@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.6.4.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison interface for Yacc-like parsers in C
    
@@ -195,7 +195,7 @@ enum { YYPUSH_MORE = 4 };
 typedef struct amp_am_yypstate amp_am_yypstate;
 
 #if defined __STDC__ || defined __cplusplus
-int amp_am_yypush_parse (amp_am_yypstate *ps, int pushed_char, YYSTYPE const *pushed_val, YYLTYPE const *pushed_loc, AmpAmScanner* scanner);
+int amp_am_yypush_parse (amp_am_yypstate *ps, int pushed_char, YYSTYPE const *pushed_val, YYLTYPE *pushed_loc, AmpAmScanner* scanner);
 #else
 int amp_am_yypush_parse ();
 #endif
