@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -121,7 +121,7 @@ static AmpNodeInfo AmpNodeInformations[] = {
 	NULL},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_PRIMARY |  ANJUTA_PROJECT_SHAREDLIB,
-	N_("Shared Library (libtool)"),
+	N_("Shared Library (Libtool)"),
 	"application/x-sharedlib",
 	"autotools-project-target-edit"},
 	AM_TOKEN__LTLIBRARIES,
@@ -739,6 +739,7 @@ amp_project_load_properties (AmpProject *project, AnjutaToken *macro, AnjutaToke
 			new_prop = anjuta_project_node_get_property (ANJUTA_PROJECT_NODE (project), info->base.id);
 			if ((new_prop != NULL) && (new_prop->info->default_value != new_prop))
 			{
+				anjuta_project_node_remove_property (ANJUTA_PROJECT_NODE (project), new_prop);
 				amp_property_free (new_prop);
 			}
 			new_prop = amp_property_new (NULL, info->token_type, info->position, NULL, args);
