@@ -1657,6 +1657,7 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	const gchar *root_uri;
 	gchar *root_dir;
 	GFile *gfile;
+	GError *error = NULL;
 	
 	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (plugin);
 
@@ -1672,9 +1673,10 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 		anjuta_cache_path = anjuta_util_get_user_cache_file_path (".", NULL);
 		if (symbol_db_engine_open_db (sdb_plugin->sdbe_globals, 
 							  anjuta_cache_path, 
-							  PROJECT_GLOBALS) == DB_OPEN_STATUS_FATAL)
+							  PROJECT_GLOBALS,
+							  &error) == DB_OPEN_STATUS_FATAL)
 		{
-			g_error ("Opening global project under %s", anjuta_cache_path);
+			g_error ("Opening global project under %s: %s", anjuta_cache_path, error->message);
 		}
 		g_free (anjuta_cache_path);
 	
@@ -1725,7 +1727,7 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 		/* we'll use the same values for db_directory and project_directory */
 		DEBUG_PRINT ("Opening db %s and project_dir %s", root_dir, root_dir);
 		gint open_status = symbol_db_engine_open_db (sdb_plugin->sdbe_project, root_dir, 
-										  root_dir);
+										  root_dir, &error);
 
 		/* is it a fresh-new project? is it an imported project with 
 		 * no 'new' symbol-db database but the 'old' one symbol-browser? 
@@ -1734,7 +1736,7 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 		switch (open_status)
 		{
 			case DB_OPEN_STATUS_FATAL:
-				g_warning ("*** Error in opening db ***");
+				g_warning ("*** Error in opening db: %s***", error->message);
 				return;
 				
 			case DB_OPEN_STATUS_NORMAL:
@@ -2012,6 +2014,7 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	gchar *anjuta_cache_path;
 	gchar *ctags_path;
 	GtkWidget *view, *label;
+	GError *error = NULL;
 	
 	DEBUG_PRINT ("SymbolDBPlugin: Activating SymbolDBPlugin plugin …");
 	
@@ -2081,9 +2084,10 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	anjuta_cache_path = anjuta_util_get_user_cache_file_path (".", NULL);
 	if (symbol_db_engine_open_db (sdb_plugin->sdbe_globals, 
 							  anjuta_cache_path, 
-							  PROJECT_GLOBALS) == DB_OPEN_STATUS_FATAL)
+							  PROJECT_GLOBALS,
+							  &error) == DB_OPEN_STATUS_FATAL)
 	{
-		g_error ("Opening global project under %s", anjuta_cache_path);
+		g_error ("Opening global project under %s: %s", anjuta_cache_path, error->message);
 	}
 	
 	g_free (anjuta_cache_path);
